@@ -5,7 +5,7 @@ import pytest
 
 
 @pytest.mark.parametrize("df", (1, 1.5, 2, 3, 4, 5.5, 10))
-def test_t_pdf(df):
+def test_pdf(df):
     x = np.linspace(-5, 5, 10)
     got = t.pdf(x, df, 2, 3)
     expected = sc.t.pdf(x, df, 2, 3)  # supports real-valued df
@@ -13,7 +13,7 @@ def test_t_pdf(df):
 
 
 @pytest.mark.parametrize("df", (1, 1.5, 3, 5.5, 10))
-def test_t_cdf(df):
+def test_cdf(df):
     x = np.linspace(-5, 5, 10)
     got = t.cdf(x, df, 2, 3)
     expected = sc.t.cdf(x, df, 2, 3)  # supports real-valued df
@@ -21,7 +21,7 @@ def test_t_cdf(df):
 
 
 @pytest.mark.parametrize("df", (1, 1.5, 3, 5.5, 10))
-def test_t_ppf(df):
+def test_ppf(df):
     x = np.linspace(0, 1, 10)
     got = t.ppf(x, df, 2, 3)
     expected = sc.t.ppf(x, df, 2, 3)  # supports real-valued df
